@@ -103,11 +103,14 @@ class _AbstractQuerySet(abc.ABC):
         """
         # No more than two results are needed, so save the server's resources.
         kwargs['limit'] = 2
-        resource_iter = iter(self.filter(**kwargs))
-        result = next(resource_iter)
+        resource_iter = self.filter(**kwargs).iterator()
+        try:
+            result = next(resource_iter)
+        except StopIteration:
+            raise NoResourcesExist(self._resource._name(), self._kwargs, kwargs)
         try:
             next(resource_iter)
-            raise MultipleResourcesReturned(self._resource._name(), kwargs, list(resource_iter))
+            raise MultipleResourcesReturned(self._resource._name(), self._kwargs, kwargs)
         except StopIteration:
             pass
         return result
@@ -229,6 +232,23 @@ class _AbstractQuerySet(abc.ABC):
         """
         return self.filter(__prefetch=list(args))
 
+    def __getstate__(self):
+        state = self.__dict__.copy()
+        state['_resource'] = state['_resource']()
+        # TODO Keep cached copies?!
+        del state['_val_retriever']
+        del state['_retrieved_resources']
+        del state['_prefetched_resources']
+        return state
+
+    def __setstate__(self, state):
+        state['_resource'] = type(state['_resource'])
+        for member, value in state.items():
+            setattr(self, member, value)
+        self._val_retriever = None
+        self._retrieved_resources = []
+        self._prefetched_resources = {k: None for k in self._prefetch}
+
 
 class QuerySet(_AbstractQuerySet):
     """Allows for easier querying of resources while reducing API access.
@@ -372,7 +392,7 @@ class QuerySet(_AbstractQuerySet):
                 stop = total_count + stop
             if start < 0:
                 raise IndexError("The index {0} is out of range.".format(orig_start))
-            if stop <= 0:
+            if stop < 0:
                 raise IndexError("The index {0} is out of range.".format(orig_stop))
         if step < 0:
             start, stop = stop + 1, start + 1
